# Generated by Django 4.1 on 2023-04-03 10:53

import tour_guide.model_fields
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django_auxiliaries.servable
import django_auxiliaries.variable_scope
import modelcluster.contrib.taggit
import modelcluster.fields
import ruminate.blocks
import ruminate.model_fields
import uuid
import wagtail.contrib.routable_page.models
import wagtail.models
import wagtail_block_model_field.fields
import wagtail_preference_blocks.blocks
import wagtail_switch_block.blocks


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('wagtailcore', '0078_referenceindex'),
        ('officekit', '0002_add_address_formats'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('wagtail_synopsis', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Article',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('translation_key', models.UUIDField(default=uuid.uuid4, editable=False)),
                ('live', models.BooleanField(default=True, editable=False, verbose_name='live')),
                ('has_unpublished_changes', models.BooleanField(default=False, editable=False, verbose_name='has unpublished changes')),
                ('first_published_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='first published at')),
                ('last_published_at', models.DateTimeField(editable=False, null=True, verbose_name='last published at')),
                ('go_live_at', models.DateTimeField(blank=True, null=True, verbose_name='go live date/time')),
                ('expire_at', models.DateTimeField(blank=True, null=True, verbose_name='expiry date/time')),
                ('expired', models.BooleanField(default=False, editable=False, verbose_name='expired')),
                ('year', models.PositiveIntegerField(default=0, editable=False)),
                ('month', models.PositiveSmallIntegerField(default=0, editable=False)),
                ('day', models.PositiveSmallIntegerField(default=0, editable=False)),
                ('slug', models.SlugField(allow_unicode=True, help_text='The name of the article as it will appear in URLs', max_length=255, verbose_name='slug')),
                ('intro', wagtail_block_model_field.fields.BlockModelField(ruminate.blocks.ArticleIntroBlock(label='Intro', required=False), wagtail_switch_block.blocks.SwitchValue)),
                ('content', ruminate.model_fields.ArticleContentField(blank=True, default='[]', help_text='An article is composed by creating one or more sections, each starting with a title and consisting of blocks of content such as text or images.')),
                ('references', ruminate.model_fields.ArticleReferencesField(blank=True, default='[]')),
                ('title', models.CharField(help_text="The article title as you'd like it to be seen by the public", max_length=255, verbose_name='title')),
                ('seo_title', models.CharField(blank=True, help_text='The name of the page displayed on search engine results as the clickable headline.', max_length=255, verbose_name='title tag')),
                ('search_description', models.TextField(blank=True, help_text='The descriptive text displayed underneath a headline in search engine results.', verbose_name='meta description')),
                ('preferences_context', wagtail_block_model_field.fields.BlockModelField(wagtail_preference_blocks.blocks.PreferencesContextBlock(label='Preferences Context'), wagtail_preference_blocks.blocks.PreferencesContext, verbose_name='Preferences')),
                ('created_by_user', models.ForeignKey(blank=True, editable=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL, verbose_name='created by user')),
                ('latest_revision', models.ForeignKey(blank=True, editable=False, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailcore.revision', verbose_name='latest revision')),
                ('live_revision', models.ForeignKey(blank=True, editable=False, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailcore.revision', verbose_name='live revision')),
                ('locale', models.ForeignKey(editable=False, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='wagtailcore.locale')),
            ],
            bases=(django_auxiliaries.variable_scope.WagtailPageMixin, models.Model, wagtail.models.PreviewableMixin, django_auxiliaries.servable.Servable),
        ),
        migrations.CreateModel(
            name='ArticleIndexPage',
            fields=[
                ('page_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='wagtailcore.page')),
                ('navigation_categories', tour_guide.model_fields.NavigationCategoriesField(blank=True, choices_function_name='tour_guide.categories.navigation_category_choices', max_length=128, verbose_name='Navigation Categories')),
            ],
            options={
                'abstract': False,
            },
            bases=(wagtail.contrib.routable_page.models.RoutablePageMixin, 'wagtailcore.page', models.Model),
        ),
        migrations.CreateModel(
            name='ArticleTag',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, unique=True, verbose_name='name')),
                ('slug', models.SlugField(allow_unicode=True, max_length=100, unique=True, verbose_name='slug')),
            ],
            options={
                'verbose_name': 'article tag',
                'verbose_name_plural': 'article tags',
            },
        ),
        migrations.CreateModel(
            name='RuminateSiteSettings',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('canonical_article_index_page', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='ruminate.articleindexpage')),
                ('site', models.OneToOneField(editable=False, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.site')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ArticleTagItem',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('content_object', modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='tagged_items', to='ruminate.article')),
                ('tag', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='tagged_article', to='ruminate.articletag')),
            ],
            options={
                'unique_together': {('content_object', 'tag')},
            },
        ),
        migrations.CreateModel(
            name='ArticleSynopsis',
            fields=[
                ('synopsis_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='wagtail_synopsis.synopsis')),
                ('model', modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='synopsis', to='ruminate.article')),
            ],
            options={
                'ordering': ['sort_order'],
                'abstract': False,
            },
            bases=('wagtail_synopsis.synopsis',),
        ),
        migrations.AddField(
            model_name='article',
            name='tags',
            field=modelcluster.contrib.taggit.ClusterTaggableManager(blank=True, help_text='A comma-separated list of tags.', through='ruminate.ArticleTagItem', to='ruminate.ArticleTag', verbose_name='Tags'),
        ),
        migrations.CreateModel(
            name='NthAuthorInArticle',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('sort_order', models.IntegerField(blank=True, editable=False, null=True)),
                ('article', modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='authors', to='ruminate.article')),
                ('author', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='articles', to='officekit.groupmember')),
            ],
            options={
                'verbose_name': 'Author in Article',
                'verbose_name_plural': 'Authors in Article',
                'ordering': ['sort_order'],
                'abstract': False,
                'unique_together': {('author', 'article')},
            },
        ),
        migrations.AlterUniqueTogether(
            name='article',
            unique_together={('translation_key', 'locale')},
        ),
    ]
